:github_url: https://github.com/stephane-caron/pink/tree/master/doc/src/inverse-kinematics.rst

******************
Inverse kinematics
******************

Joint limits
============

.. automodule:: pink.limits
    :members:

Configured robots
=================

.. automodule:: pink.configured_robot
    :members:

Solving joint velocities
========================

.. automodule:: pink.solve_ik
    :members:
